@@ -61,7 +61,8 @@ Utility functions and constants usable in various circumstances.
       (produced by `tesserocr`)
     * `y0x0y1x1` is the same as `x0y0x1y1` with positions of `x` and `y` in the list swapped
 
-* :py:func:`is_local_filename`,
+* :py:func:`is_file_in_directory`
+  :py:func:`is_local_filename`,
   :py:func:`safe_filename`,
   :py:func:`abspath`,
   :py:func:`get_local_filename`
@@ -114,8 +115,7 @@ from .constants import (
     LOG_FORMAT,
     LOG_TIMEFMT,
     VERSION,
-    XDG_CONFIG_HOME,
-    XDG_DATA_HOME)
+    )
 
 from .deprecate import (
     deprecated_alias)
@@ -165,11 +165,14 @@ from .logging import (
 
 from .os import (
     abspath,
+    get_processor_resource_types,
     list_all_resources,
+    is_file_in_directory,
     list_resource_candidates,
     atomic_write,
     pushd_popd,
-    unzip_file_to_dir)
+    unzip_file_to_dir,
+    )
 
 from .str import (
     assert_file_grp_cardinality,
